@@ -8,48 +8,48 @@
 */
 
 /* .Call calls */
-extern SEXP _cna_C_append_intList(SEXP, SEXP);
-extern SEXP _cna_C_charList2string(SEXP, SEXP, SEXP, SEXP);
-extern SEXP _cna_C_checkHall_k(SEXP, SEXP);
-extern SEXP _cna_C_checkHallsCondition(SEXP);
-extern SEXP _cna_C_concat(SEXP, SEXP);
-extern SEXP _cna_C_conCov(SEXP, SEXP, SEXP);
-extern SEXP _cna_C_conj_conCov(SEXP, SEXP, SEXP, SEXP);
-extern SEXP _cna_C_conjScore(SEXP, SEXP);
-extern SEXP _cna_C_countUniques(SEXP);
-extern SEXP _cna_C_disj_conCov(SEXP, SEXP, SEXP, SEXP);
-extern SEXP _cna_C_disj_contained(SEXP, SEXP, SEXP);
-extern SEXP _cna_C_duplicatedMat(SEXP);
-extern SEXP _cna_C_find_asf(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP _cna_C_find_first_false(SEXP);
-extern SEXP _cna_C_hasSubsetIn(SEXP, SEXP);
-extern SEXP _cna_C_hasSubsetInM(SEXP, SEXP);
-extern SEXP _cna_C_hasSupersetIn(SEXP, SEXP, SEXP);
-extern SEXP _cna_C_increment(SEXP, SEXP, SEXP, SEXP);
-extern SEXP _cna_C_init_ii(SEXP, SEXP);
-extern SEXP _cna_C_intList_minimal_old(SEXP, SEXP, SEXP);
-extern SEXP _cna_C_is_submodel(SEXP, SEXP, SEXP);
-extern SEXP _cna_C_isSubsetOf(SEXP, SEXP);
-extern SEXP _cna_C_max_which(SEXP);
-extern SEXP _cna_C_mconcat(SEXP, SEXP, SEXP);
-extern SEXP _cna_C_minimal(SEXP, SEXP, SEXP);
-extern SEXP _cna_C_minimal_old(SEXP, SEXP, SEXP);
-extern SEXP _cna_C_mredund(SEXP, SEXP);
-extern SEXP _cna_C_recCharList2char(SEXP, SEXP, SEXP, SEXP);
-extern SEXP _cna_C_redund(SEXP);
-extern SEXP _cna_C_relist_Char(SEXP, SEXP);
-extern SEXP _cna_C_relist_Int(SEXP, SEXP);
-extern SEXP _cna_C_relist_List(SEXP, SEXP);
-extern SEXP _cna_C_relist_Log(SEXP, SEXP);
-extern SEXP _cna_C_relist_Num(SEXP, SEXP);
-extern SEXP _cna_C_rowSubsetColAnys(SEXP, SEXP);
-extern SEXP _cna_C_selectCols(SEXP, SEXP);
-extern SEXP _cna_C_set_lim(SEXP, SEXP);
-extern SEXP _cna_C_subsetMin(SEXP, SEXP);
-extern SEXP _cna_C_uniqueCombs(SEXP, SEXP);
-extern SEXP _cna_C_uniqueMat(SEXP);
-extern SEXP _cna_C_varies(SEXP, SEXP, SEXP);
-extern SEXP _cna_intList_equal(SEXP, SEXP);
+extern SEXP _cna_C_append_intList(void *, void *);
+extern SEXP _cna_C_charList2string(void *, void *, void *, void *);
+extern SEXP _cna_C_checkHall_k(void *, void *);
+extern SEXP _cna_C_checkHallsCondition(void *);
+extern SEXP _cna_C_concat(void *, void *);
+extern SEXP _cna_C_conCov(void *, void *, void *);
+extern SEXP _cna_C_conj_conCov(void *, void *, void *, void *);
+extern SEXP _cna_C_conjScore(void *, void *);
+extern SEXP _cna_C_countUniques(void *);
+extern SEXP _cna_C_disj_conCov(void *, void *, void *, void *);
+extern SEXP _cna_C_disj_contained(void *, void *, void *);
+extern SEXP _cna_C_duplicatedMat(void *);
+extern SEXP _cna_C_find_asf(void *, void *, void *, void *, void *, void *, void *);
+extern SEXP _cna_C_find_first_false(void *);
+extern SEXP _cna_C_hasSubsetIn(void *, void *);
+extern SEXP _cna_C_hasSubsetInM(void *, void *);
+extern SEXP _cna_C_hasSupersetIn(void *, void *, void *);
+extern SEXP _cna_C_increment(void *, void *, void *, void *);
+extern SEXP _cna_C_init_ii(void *, void *);
+extern SEXP _cna_C_intList_minimal_old(void *, void *, void *);
+extern SEXP _cna_C_is_submodel(void *, void *, void *);
+extern SEXP _cna_C_isSubsetOf(void *, void *);
+extern SEXP _cna_C_max_which(void *);
+extern SEXP _cna_C_mconcat(void *, void *, void *);
+extern SEXP _cna_C_minimal(void *, void *, void *);
+extern SEXP _cna_C_minimal_old(void *, void *, void *);
+extern SEXP _cna_C_mredund(void *, void *);
+extern SEXP _cna_C_recCharList2char(void *, void *, void *, void *);
+extern SEXP _cna_C_redund(void *);
+extern SEXP _cna_C_relist_Char(void *, void *);
+extern SEXP _cna_C_relist_Int(void *, void *);
+extern SEXP _cna_C_relist_List(void *, void *);
+extern SEXP _cna_C_relist_Log(void *, void *);
+extern SEXP _cna_C_relist_Num(void *, void *);
+extern SEXP _cna_C_rowSubsetColAnys(void *, void *);
+extern SEXP _cna_C_selectCols(void *, void *);
+extern SEXP _cna_C_set_lim(void *, void *);
+extern SEXP _cna_C_subsetMin(void *, void *);
+extern SEXP _cna_C_uniqueCombs(void *, void *);
+extern SEXP _cna_C_uniqueMat(void *);
+extern SEXP _cna_C_varies(void *, void *, void *);
+extern SEXP _cna_intList_equal(void *, void *);
 
 static const R_CallMethodDef CallEntries[] = {
     {"_cna_C_append_intList",      (DL_FUNC) &_cna_C_append_intList,      2},
